@@ -80,18 +80,32 @@ Perl_ck_warner(pTHX_ U32 err, const char* pat, ...)
 
 #if PERL_VERSION_GE(5,9,0)
 
-#  define VUTIL_USE_TWO_SUFFIX 1
+#  define VUTIL_REPLACE_CORE 1
 
 const char * Perl_scan_version2(pTHX_ const char *s, SV *rv, bool qv);
 SV * Perl_new_version2(pTHX_ SV *ver);
 SV * Perl_upg_version2(pTHX_ SV *sv, bool qv);
 SV * Perl_vstringify2(pTHX_ SV *vs);
 SV * Perl_vverify2(pTHX_ SV *vs);
+SV * Perl_vnumify2(pTHX_ SV *vs);
+SV * Perl_vnormal2(pTHX_ SV *vs);
+SV * Perl_vstringify2(pTHX_ SV *vs);
+int Perl_vcmp2(pTHX_ SV *lsv, SV *rsv);
+const char * Perl_prescan_version2(pTHX_ const char *s, bool strict, const char** errstr, bool *sqv, int *ssaw_decimal, int *swidth, bool *salpha);
+
 #  define SCAN_VERSION(a,b,c)	Perl_scan_version2(aTHX_ a,b,c)
-#  define NEW_VERSION(a)		Perl_new_version2(aTHX_ a)
+#  define NEW_VERSION(a)	Perl_new_version2(aTHX_ a)
 #  define UPG_VERSION(a,b)	Perl_upg_version2(aTHX_ a, b)
 #  define VSTRINGIFY(a)		Perl_vstringify2(aTHX_ a)
 #  define VVERIFY(a)		Perl_vverify2(aTHX_ a)
+#  define VNUMIFY(a)		Perl_vnumify2(aTHX_ a)
+#  define VNORMAL(a)		Perl_vnormal2(aTHX_ a)
+#  define VCMP(a,b)		Perl_vcmp2(aTHX_ a,b)
+#  define PRESCAN_VERSION(a,b,c,d,e,f,g)	Perl_prescan_version2(aTHX_ a,b,c,d,e,f,g)
+#  define is_LAX_VERSION(a,b) \
+	(a != Perl_prescan_version2(aTHX_ a, FALSE, b, NULL, NULL, NULL, NULL))
+#  define is_STRICT_VERSION(a,b) \
+	(a != Perl_prescan_version2(aTHX_ a, TRUE, b, NULL, NULL, NULL, NULL))
 
 #else
 
@@ -103,31 +117,26 @@ SV * Perl_vnumify(pTHX_ SV *vs);
 SV * Perl_vnormal(pTHX_ SV *vs);
 SV * Perl_vstringify(pTHX_ SV *vs);
 int Perl_vcmp(pTHX_ SV *lsv, SV *rsv);
+const char * Perl_prescan_version(pTHX_ const char *s, bool strict, const char** errstr, bool *sqv, int *ssaw_decimal, int *swidth, bool *salpha);
+
 #  define SCAN_VERSION(a,b,c)	Perl_scan_version(aTHX_ a,b,c)
-#  define NEW_VERSION(a)		Perl_new_version(aTHX_ a)
+#  define NEW_VERSION(a)	Perl_new_version(aTHX_ a)
 #  define UPG_VERSION(a,b)	Perl_upg_version(aTHX_ a, b)
 #  define VSTRINGIFY(a)		Perl_vstringify(aTHX_ a)
 #  define VVERIFY(a)		Perl_vverify(aTHX_ a)
-#  define vnumify(a)		Perl_vnumify(aTHX_ a)
-#  define vnormal(a)		Perl_vnormal(aTHX_ a)
-#  define voriginal(a)		Perl_voriginal(aTHX_ a)
-#  define vcmp(a,b)		Perl_vcmp(aTHX_ a,b)
+#  define VNUMIFY(a)		Perl_vnumify(aTHX_ a)
+#  define VNORMAL(a)		Perl_vnormal(aTHX_ a)
+#  define VCMP(a,b)		Perl_vcmp(aTHX_ a,b)
+
+#  define PRESCAN_VERSION(a,b,c,d,e,f,g)	Perl_prescan_version(aTHX_ a,b,c,d,e,f,g)
+#  define is_LAX_VERSION(a,b) \
+	(a != Perl_prescan_version(aTHX_ a, FALSE, b, NULL, NULL, NULL, NULL))
+#  define is_STRICT_VERSION(a,b) \
+	(a != Perl_prescan_version(aTHX_ a, TRUE, b, NULL, NULL, NULL, NULL))
 
 #endif
 
 #if PERL_VERSION_LT(5,11,4)
-const char *
-Perl_prescan_version(pTHX_ const char *s, bool strict,
-		     const char** errstr,
-		     bool *sqv, int *ssaw_decimal, int *swidth, bool *salpha);
-#  define prescan_version(a,b,c,d,e,f,g)	Perl_prescan_version(aTHX_ a,b,c,d,e,f,g)
-
-#  define is_LAX_VERSION(a,b) \
-	(a != Perl_prescan_version(aTHX_ a, FALSE, b, NULL, NULL, NULL, NULL))
-
-#  define is_STRICT_VERSION(a,b) \
-	(a != Perl_prescan_version(aTHX_ a, TRUE, b, NULL, NULL, NULL, NULL))
-
 #  define BADVERSION(a,b,c) \
 	if (b) { \
 	    *b = c; \
@@ -156,5 +165,4 @@ Perl_prescan_version(pTHX_ const char *s, bool strict,
 	assert(lhv); assert(rhv)
 #  define PERL_ARGS_ASSERT_CK_WARNER      \
 	assert(pat)
-
 #endif
